"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const React = __importStar(require("react"));
const ContextMenu_1 = __importDefault(require("./ContextMenu"));
const getMenuLabelName_1 = __importDefault(require("./common/getMenuLabelName"));
class MenuBar extends React.Component {
    constructor(props) {
        super(props);
        this.onMousedownBody = (ev) => {
            var el = ev.target;
            if (this.containerRef.current) {
                if (el && el instanceof Node && !this.containerRef.current.contains(el)) {
                    this.setState({ active: false, openedMenuIndex: -1 });
                    document.body.removeEventListener('mousedown', this.onMousedownBody);
                    window.removeEventListener('keydown', this.onKeyDownWindow);
                }
            }
        };
        this.onKeyDownWindow = (ev) => {
            const { altKey, shiftKey, ctrlKey, metaKey, which } = ev;
            this.keydownInfo = [shiftKey, ctrlKey, metaKey, which].join('-');
        };
        this.onKeyUpWindow = (ev) => {
            // const { altKey, shiftKey, ctrlKey, metaKey, which } = ev;
            // const keyupInfo = [shiftKey, ctrlKey, metaKey, which].join('-');
            // console.log(this.keydownInfo, keyupInfo, this.keydownInfo === keyupInfo);
        };
        this.handleMenuBarActive = () => {
            this.setState({
                active: true,
            });
            document.body.addEventListener('mousedown', this.onMousedownBody);
        };
        this.handleMenuClick = (e, menuIndex) => {
            this.handleSubmenuPopup(e, menuIndex);
        };
        this.handleMenuOver = (e, menuIndex) => {
            const { active } = this.state;
            if (!active) {
                return;
            }
            this.handleSubmenuPopup(e, menuIndex);
        };
        this.handleSubmenuPopup = (e, menuIndex) => {
            const { items = [] } = this.props;
            const item = items[menuIndex];
            const submenu = this.childMenu[menuIndex];
            if (!submenu || !item) {
                return;
            }
            if (!e.currentTarget) {
                return;
            }
            if (!this.containerRef.current) {
                return;
            }
            const { openedMenuIndex = -1 } = this.state;
            const { pageXOffset, pageYOffset } = window;
            const { left, top, height } = e.currentTarget.getBoundingClientRect();
            if (openedMenuIndex !== menuIndex) {
                this.childMenu[openedMenuIndex] &&
                    this.childMenu[openedMenuIndex].close();
            }
            // submenu.setMenu(item.submenu || []);
            submenu.popup({ x: left + pageXOffset, y: top + height + pageYOffset });
            this.setState({
                openedMenuIndex: menuIndex,
            });
        };
        this.initSubmenu = () => {
            const { items = [], submenu: { style: _submenuStyle = {}, placement = 'bottom' } = {}, } = this.props;
            const submenuStyle = Object.assign({}, _submenuStyle);
            if (placement === 'bottom') {
                submenuStyle.borderTopLeftRadius = 0;
                submenuStyle.borderTopRightRadius = 0;
                submenuStyle.marginTop = 0;
            }
            this.childMenu = [];
            items.forEach((menu, i) => {
                const submenu = new ContextMenu_1.default({
                    id: `menu-${i}`,
                    style: submenuStyle,
                    placement,
                });
                submenu.setMenu(menu.submenu || []);
                this.childMenu.push(submenu);
            });
        };
        this.childMenu = [];
        this.containerRef = React.createRef();
        this.state = {
            active: false,
            altKeyPressed: false,
            openedMenuIndex: -1,
        };
    }
    componentDidMount() {
        const { enableAltKeyAction } = this.props;
        this.initSubmenu();
        if (enableAltKeyAction) {
            window.addEventListener('keydown', this.onKeyDownWindow, false);
            window.addEventListener('keyup', this.onKeyUpWindow, false);
        }
    }
    componentDidUpdate(prevProps) {
        if (prevProps.items !== this.props.items) {
            this.initSubmenu();
        }
    }
    componentWillUnmount() {
        const { enableAltKeyAction } = this.props;
        if (enableAltKeyAction) {
            window.removeEventListener('keydown', this.onKeyDownWindow);
            window.removeEventListener('keyup', this.onKeyUpWindow);
        }
    }
    render() {
        const { active, altKeyPressed, openedMenuIndex } = this.state;
        const { items = [], style } = this.props;
        const menuBarStyle = Object.assign({}, style);
        return (React.createElement("div", { ref: this.containerRef, className: `rewm-menubar${active ? ' rewm-menubar-active' : ''}`, style: menuBarStyle }, items.map((menu, mi) => {
            return (React.createElement("div", { className: `${openedMenuIndex === mi ? 'active' : ''}`, key: mi, "data-menubar-item": true, onMouseDown: () => {
                    this.handleMenuBarActive();
                }, onClick: e => {
                    this.handleMenuClick(e, mi);
                }, onMouseOver: e => {
                    this.handleMenuOver(e, mi);
                } }, getMenuLabelName_1.default(menu.label, altKeyPressed)));
        })));
    }
}
exports.default = MenuBar;
