"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.KeymapDisplay = void 0;
const React = __importStar(require("react"));
const CheckboxIcon_1 = __importDefault(require("./CheckboxIcon"));
const SubmenuIcon_1 = __importDefault(require("./SubmenuIcon"));
const Submenu_1 = __importDefault(require("./Submenu"));
const platform = typeof window !== 'undefined' ? window.navigator.platform : process.platform;
const macosPlatforms = ['Macintosh', 'MacIntel', 'MacPPC', 'Mac68K', 'darwin'];
const windowsPlatforms = ['Win32', 'Win64', 'Windows', 'WinCE', 'win32'];
const is = {
    macos: macosPlatforms.indexOf(platform) !== -1,
    linux: macosPlatforms.indexOf(platform) === -1 &&
        windowsPlatforms.indexOf(platform) === -1,
    windows: windowsPlatforms.indexOf(platform) !== -1,
};
function KeymapDisplay(key) {
    if (!key) {
        return '';
    }
    const chars = {
        Command: '⌘',
        Cmd: '⌘',
        Control: 'Ctrl',
        Ctrl: 'Ctrl',
        CommandOrControl: is.macos ? '⌘' : 'Ctrl',
        CmdOrCtrl: is.macos ? '⌘' : 'Ctrl',
        Alt: is.macos ? '⌥' : 'Alt',
        Option: '⌥',
        Shift: is.macos ? '⇧' : 'Shift',
        Return: is.macos ? '↵' : 'Enter',
    };
    return key
        .split(/\+/g)
        .map(s => {
        if (typeof chars[s] === 'undefined') {
            return s;
        }
        else {
            return chars[s];
        }
    })
        .join(' + ');
}
exports.KeymapDisplay = KeymapDisplay;
class MenuItem extends React.Component {
    constructor(props) {
        super(props);
        this.itemRef = React.createRef();
    }
    render() {
        const { item, onClickItem, onHoverItem } = this.props;
        const { type = 'normal', label, icon, checked, submenu, click, enabled = true, visible = true, } = item;
        const itemProps = {};
        if (!visible) {
            return null;
        }
        switch (type) {
            case 'normal':
            case 'checkbox':
                itemProps['data-ctx-item'] = true;
                itemProps['data-enabled'] = enabled;
                if (item.opened) {
                    itemProps['data-opened'] = true;
                }
                return (React.createElement("div", Object.assign({ ref: this.itemRef }, itemProps, { onClick: e => {
                        // has click and dont have submenu
                        if (!item.submenu && enabled) {
                            onClickItem(item, window, e);
                            if (click) {
                                click(item, window, e);
                            }
                        }
                    }, onMouseOver: e => {
                        onHoverItem(item, e, true);
                    } }),
                    React.createElement("div", { "data-checkbox": true }, item.checked && React.createElement(CheckboxIcon_1.default, null)),
                    React.createElement("div", { "data-label": true },
                        icon && React.createElement("span", { "data-label-icon": true }, icon),
                        item.label),
                    item.submenu ? (React.createElement(React.Fragment, null,
                        React.createElement(SubmenuIcon_1.default, null),
                        item.opened && (React.createElement(Submenu_1.default, { submenu: item.submenu, onClickItem: onClickItem, itemRef: this.itemRef })))) : (React.createElement("div", { "data-accelerator": true }, KeymapDisplay(item.accelerator)))));
            case 'separator':
                itemProps['data-ctx-separator'] = true;
                return React.createElement("div", Object.assign({}, itemProps));
            default:
                return null;
        }
    }
}
exports.default = MenuItem;
